==> haskell-cryptohash-md5-0.11.100.1-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-cryptohash-md5.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptohash-md5
version: 0.11.100.1
id: cryptohash-md5-0.11.100.1-C9GYF44B4VH54L80n64dS7
key: cryptohash-md5-0.11.100.1-C9GYF44B4VH54L80n64dS7
license: BSD-3-Clause
copyright: Vincent Hanquez, Herbert Valerio Riedel
maintainer: Herbert Valerio Riedel <hvr@gnu.org>
homepage: https://github.com/hvr/cryptohash-md5
synopsis: Fast, pure and practical MD5 implementation
description:
    A practical incremental and one-pass, pure API to the
    <https://en.wikipedia.org/wiki/MD5 MD5 hash algorithm>
    (including <https://en.wikipedia.org/wiki/HMAC HMAC> support)
    with performance close to the fastest implementations available in other languages.
    .
    The implementation is made in C with a haskell FFI wrapper that hides the C implementation.
    .
    NOTE: This package has been forked off @cryptohash-0.11.7@ because the @cryptohash@ package
    has been deprecated and so this package continues to satisfy the need for a lightweight package
    providing the MD5 hash algorithm without any dependencies on packages other than
    @base@ and @bytestring@.
    .
    Consequently, this package can be used as a drop-in replacement for @cryptohash@'\''s
    "Crypto.Hash.MD5" module, though with a clearly smaller footprint.
category: Data, Cryptography
abi: 5236cc6b0c5edb80dd40335491d9d792
exposed: True
exposed-modules:
    Crypto.Hash.MD5
import-dirs: /usr/lib/ghc-8.4.3/site-local/cryptohash-md5-0.11.100.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/cryptohash-md5-0.11.100.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/cryptohash-md5-0.11.100.1
hs-libraries: HScryptohash-md5-0.11.100.1-C9GYF44B4VH54L80n64dS7
depends:
    base-4.11.1.0 bytestring-0.10.8.2
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
haddock-interfaces: /usr/share/doc/haskell-cryptohash-md5/html/cryptohash-md5.haddock
haddock-html: /usr/share/doc/haskell-cryptohash-md5/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cryptohash-md5-0.11.100.1-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-cryptohash-md5.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptohash-md5
version: 0.11.100.1
id: cryptohash-md5-0.11.100.1-4xpVEo8eyQi2XbS8mfTUTa
key: cryptohash-md5-0.11.100.1-4xpVEo8eyQi2XbS8mfTUTa
license: BSD-3-Clause
copyright: Vincent Hanquez, Herbert Valerio Riedel
maintainer: Herbert Valerio Riedel <hvr@gnu.org>
homepage: https://github.com/hvr/cryptohash-md5
synopsis: Fast, pure and practical MD5 implementation
description:
    A practical incremental and one-pass, pure API to the
    <https://en.wikipedia.org/wiki/MD5 MD5 hash algorithm>
    (including <https://en.wikipedia.org/wiki/HMAC HMAC> support)
    with performance close to the fastest implementations available in other languages.
    .
    The implementation is made in C with a haskell FFI wrapper that hides the C implementation.
    .
    NOTE: This package has been forked off @cryptohash-0.11.7@ because the @cryptohash@ package
    has been deprecated and so this package continues to satisfy the need for a lightweight package
    providing the MD5 hash algorithm without any dependencies on packages other than
    @base@ and @bytestring@.
    .
    Consequently, this package can be used as a drop-in replacement for @cryptohash@'\''s
    "Crypto.Hash.MD5" module, though with a clearly smaller footprint.
category: Data, Cryptography
abi: af8b482e1281640c6693c3ee552d68e0
exposed: True
exposed-modules:
    Crypto.Hash.MD5
import-dirs: /usr/lib/ghc-8.6.1/site-local/cryptohash-md5-0.11.100.1
library-dirs: /usr/lib/ghc-8.6.1/site-local/cryptohash-md5-0.11.100.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/cryptohash-md5-0.11.100.1
hs-libraries: HScryptohash-md5-0.11.100.1-4xpVEo8eyQi2XbS8mfTUTa
depends:
    base-4.12.0.0 bytestring-0.10.8.2
haddock-interfaces: /usr/share/doc/haskell-cryptohash-md5/html/cryptohash-md5.haddock
haddock-html: /usr/share/doc/haskell-cryptohash-md5/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
